@@ -1,12 +1,11 @@
+from pfrl.experiments.evaluation_hooks import EvaluationHook  # NOQA
+from pfrl.experiments.evaluation_hooks import OptunaPrunerHook  # NOQA
 from pfrl.experiments.evaluator import eval_performance  # NOQA
-
 from pfrl.experiments.hooks import LinearInterpolationHook  # NOQA
 from pfrl.experiments.hooks import StepHook  # NOQA
-
-from pfrl.experiments.prepare_output_dir import is_under_git_control  # NOQA
 from pfrl.experiments.prepare_output_dir import generate_exp_id  # NOQA
+from pfrl.experiments.prepare_output_dir import is_under_git_control  # NOQA
 from pfrl.experiments.prepare_output_dir import prepare_output_dir  # NOQA
-
 from pfrl.experiments.train_agent import train_agent  # NOQA
 from pfrl.experiments.train_agent import train_agent_with_evaluation  # NOQA
 from pfrl.experiments.train_agent_async import train_agent_async  # NOQA
