@@ -10,13 +10,19 @@ import pfrl
 
 
 def _run_episodes(
-    env, agent, n_steps, n_episodes, max_episode_len=None, logger=None,
+    env,
+    agent,
+    n_steps,
+    n_episodes,
+    max_episode_len=None,
+    logger=None,
 ):
     """Run multiple episodes and return returns."""
     assert (n_steps is None) != (n_episodes is None)
 
     logger = logger or logging.getLogger(__name__)
     scores = []
+    lengths = []
     terminate = False
     timestep = 0
 
@@ -42,6 +48,7 @@ def _run_episodes(
             # As mixing float and numpy float causes errors in statistics
             # functions, here every score is cast to float.
             scores.append(float(test_r))
+            lengths.append(float(episode_len))
         if n_steps is None:
             terminate = len(scores) >= n_episodes
         else:
@@ -49,14 +56,20 @@ def _run_episodes(
     # If all steps were used for a single unfinished episode
     if len(scores) == 0:
         scores.append(float(test_r))
+        lengths.append(float(episode_len))
         logger.info(
             "evaluation episode %s length:%s R:%s", len(scores), episode_len, test_r
         )
-    return scores
+    return scores, lengths
 
 
 def run_evaluation_episodes(
-    env, agent, n_steps, n_episodes, max_episode_len=None, logger=None,
+    env,
+    agent,
+    n_steps,
+    n_episodes,
+    max_episode_len=None,
+    logger=None,
 ):
     """Run multiple evaluation episodes and return returns.
 
@@ -85,7 +98,12 @@ def run_evaluation_episodes(
 
 
 def _batch_run_episodes(
-    env, agent, n_steps, n_episodes, max_episode_len=None, logger=None,
+    env,
+    agent,
+    n_steps,
+    n_episodes,
+    max_episode_len=None,
+    logger=None,
 ):
     """Run multiple episodes and return returns in a batch manner."""
     assert (n_steps is None) != (n_episodes is None)
@@ -192,11 +210,18 @@ def _batch_run_episodes(
         zip(eval_episode_lens, eval_episode_returns)
     ):
         logger.info("evaluation episode %s length: %s R: %s", i, epi_len, epi_ret)
-    return [float(r) for r in eval_episode_returns]
+    scores = [float(r) for r in eval_episode_returns]
+    lengths = [float(ln) for ln in eval_episode_lens]
+    return scores, lengths
 
 
 def batch_run_evaluation_episodes(
-    env, agent, n_steps, n_episodes, max_episode_len=None, logger=None,
+    env,
+    agent,
+    n_steps,
+    n_episodes,
+    max_episode_len=None,
+    logger=None,
 ):
     """Run multiple evaluation episodes and return returns in a batch manner.
 
@@ -248,7 +273,7 @@ def eval_performance(
     assert (n_steps is None) != (n_episodes is None)
 
     if isinstance(env, pfrl.env.VectorEnv):
-        scores = batch_run_evaluation_episodes(
+        scores, lengths = batch_run_evaluation_episodes(
             env,
             agent,
             n_steps,
@@ -257,7 +282,7 @@ def eval_performance(
             logger=logger,
         )
     else:
-        scores = run_evaluation_episodes(
+        scores, lengths = run_evaluation_episodes(
             env,
             agent,
             n_steps,
@@ -272,6 +297,11 @@ def eval_performance(
         stdev=statistics.stdev(scores) if len(scores) >= 2 else 0.0,
         max=np.max(scores),
         min=np.min(scores),
+        length_mean=statistics.mean(lengths),
+        length_median=statistics.median(lengths),
+        length_stdev=statistics.stdev(lengths) if len(lengths) >= 2 else 0,
+        length_max=np.max(lengths),
+        length_min=np.min(lengths),
     )
     return stats
 
@@ -289,7 +319,10 @@ def create_tb_writer(outdir):
     tb_writer = SummaryWriter(log_dir=outdir)
     layout = {
         "Aggregate Charts": {
-            "mean w/ min-max": ["Margin", ["eval/mean", "eval/min", "eval/max"],],
+            "mean w/ min-max": [
+                "Margin",
+                ["eval/mean", "eval/min", "eval/max"],
+            ],
             "mean +/- std": [
                 "Margin",
                 ["eval/mean", "extras/meanplusstdev", "extras/meanminusstdev"],
@@ -372,6 +405,9 @@ class Evaluator(object):
         outdir (str): Path to a directory to save things.
         max_episode_len (int): Maximum length of episodes used in evaluations.
         step_offset (int): Offset of steps used to schedule evaluations.
+        evaluation_hooks (Sequence): Sequence of
+            pfrl.experiments.evaluation_hooks.EvaluationHook objects. They are
+            called after each evaluation.
         save_best_so_far_agent (bool): If set to True, after each evaluation,
             if the score (= mean of returns in evaluation episodes) exceeds
             the best-so-far score, the current agent is saved.
@@ -388,6 +424,7 @@ class Evaluator(object):
         outdir,
         max_episode_len=None,
         step_offset=0,
+        evaluation_hooks=(),
         save_best_so_far_agent=True,
         logger=None,
         use_tensorboard=False,
@@ -409,6 +446,7 @@ class Evaluator(object):
         self.max_episode_len = max_episode_len
         self.step_offset = step_offset
         self.prev_eval_t = self.step_offset - self.step_offset % self.eval_interval
+        self.evaluation_hooks = evaluation_hooks
         self.save_best_so_far_agent = save_best_so_far_agent
         self.logger = logger or logging.getLogger(__name__)
         self.env_get_stats = getattr(self.env, "get_statistics", lambda: [])
@@ -457,6 +495,17 @@ class Evaluator(object):
         if self.use_tensorboard:
             record_tb_stats(self.tb_writer, agent_stats, eval_stats, env_stats, t)
 
+        for hook in self.evaluation_hooks:
+            hook(
+                env=self.env,
+                agent=self.agent,
+                evaluator=self,
+                step=t,
+                eval_stats=eval_stats,
+                agent_stats=agent_stats,
+                env_stats=env_stats,
+            )
+
         if mean > self.max_score:
             self.logger.info("The best score is updated %s -> %s", self.max_score, mean)
             self.max_score = mean
@@ -482,6 +531,9 @@ class AsyncEvaluator(object):
         outdir (str): Path to a directory to save things.
         max_episode_len (int): Maximum length of episodes used in evaluations.
         step_offset (int): Offset of steps used to schedule evaluations.
+        evaluation_hooks (Sequence): Sequence of
+            pfrl.experiments.evaluation_hooks.EvaluationHook objects. They are
+            called after each evaluation.
         save_best_so_far_agent (bool): If set to True, after each evaluation,
             if the score (= mean return of evaluation episodes) exceeds
             the best-so-far score, the current agent is saved.
@@ -495,6 +547,7 @@ class AsyncEvaluator(object):
         outdir,
         max_episode_len=None,
         step_offset=0,
+        evaluation_hooks=(),
         save_best_so_far_agent=True,
         logger=None,
     ):
@@ -510,6 +563,7 @@ class AsyncEvaluator(object):
         self.outdir = outdir
         self.max_episode_len = max_episode_len
         self.step_offset = step_offset
+        self.evaluation_hooks = evaluation_hooks
         self.save_best_so_far_agent = save_best_so_far_agent
         self.logger = logger or logging.getLogger(__name__)
 
@@ -572,6 +626,17 @@ class AsyncEvaluator(object):
         if self.record_tb_stats_queue is not None:
             self.record_tb_stats_queue.put([agent_stats, eval_stats, env_stats, t])
 
+        for hook in self.evaluation_hooks:
+            hook(
+                env=env,
+                agent=agent,
+                evaluator=self,
+                step=t,
+                eval_stats=eval_stats,
+                agent_stats=agent_stats,
+                env_stats=env_stats,
+            )
+
         with self._max_score.get_lock():
             if mean > self._max_score.value:
                 self.logger.info(
