@@ -162,12 +162,14 @@ def train_agent_async(
     agent=None,
     make_agent=None,
     global_step_hooks=[],
+    evaluation_hooks=(),
     save_best_so_far_agent=True,
     use_tensorboard=False,
     logger=None,
     random_seeds=None,
     stop_event=None,
     exception_event=None,
+    use_shared_memory=True,
 ):
     """Train agent asynchronously using multiprocessing.
 
@@ -193,6 +195,9 @@ def train_agent_async(
         global_step_hooks (list): List of callable objects that accepts
             (env, agent, step) as arguments. They are called every global
             step. See pfrl.experiments.hooks.
+        evaluation_hooks (Sequence): Sequence of
+            pfrl.experiments.evaluation_hooks.EvaluationHook objects. They are
+            called after each evaluation.
         save_best_so_far_agent (bool): If set to True, after each evaluation,
             if the score (= mean return of evaluation episodes) exceeds
             the best-so-far score, the current agent is saved.
@@ -206,13 +211,17 @@ def train_agent_async(
             other thread raised an excpetion. The train will be terminated and
             the current agent will be saved.
             If set to None, a new Event object is created and used internally.
+        use_shared_memory (bool): Share memory amongst asynchronous agents.
 
     Returns:
         Trained agent.
     """
-
     logger = logger or logging.getLogger(__name__)
 
+    for hook in evaluation_hooks:
+        if not hook.support_train_agent_async:
+            raise ValueError("{} does not support train_agent_async().".format(hook))
+
     # Prevent numpy from using multiple threads
     os.environ["OMP_NUM_THREADS"] = "1"
 
@@ -225,22 +234,23 @@ def train_agent_async(
     if exception_event is None:
         exception_event = mp.Event()
 
-    if agent is None:
-        assert make_agent is not None
-        agent = make_agent(0)
+    if use_shared_memory:
+        if agent is None:
+            assert make_agent is not None
+            agent = make_agent(0)
 
-    # Move model and optimizer states in shared memory
-    for attr in agent.shared_attributes:
-        attr_value = getattr(agent, attr)
-        if isinstance(attr_value, nn.Module):
-            for k, v in attr_value.state_dict().items():
-                v.share_memory_()
-        elif isinstance(attr_value, torch.optim.Optimizer):
-            for param, state in attr_value.state_dict()["state"].items():
-                assert isinstance(state, dict)
-                for k, v in state.items():
-                    if isinstance(v, torch.Tensor):
-                        v.share_memory_()
+        # Move model and optimizer states in shared memory
+        for attr in agent.shared_attributes:
+            attr_value = getattr(agent, attr)
+            if isinstance(attr_value, nn.Module):
+                for k, v in attr_value.state_dict().items():
+                    v.share_memory_()
+            elif isinstance(attr_value, torch.optim.Optimizer):
+                for param, state in attr_value.state_dict()["state"].items():
+                    assert isinstance(state, dict)
+                    for k, v in state.items():
+                        if isinstance(v, torch.Tensor):
+                            v.share_memory_()
 
     if eval_interval is None:
         evaluator = None
@@ -252,6 +262,7 @@ def train_agent_async(
             outdir=outdir,
             max_episode_len=max_episode_len,
             step_offset=step_offset,
+            evaluation_hooks=evaluation_hooks,
             save_best_so_far_agent=save_best_so_far_agent,
             logger=logger,
         )
@@ -271,8 +282,9 @@ def train_agent_async(
             eval_env = make_env(process_idx, test=True)
         if make_agent is not None:
             local_agent = make_agent(process_idx)
-            for attr in agent.shared_attributes:
-                setattr(local_agent, attr, getattr(agent, attr))
+            if use_shared_memory:
+                for attr in agent.shared_attributes:
+                    setattr(local_agent, attr, getattr(agent, attr))
         else:
             local_agent = agent
         local_agent.process_idx = process_idx
