@@ -2,7 +2,8 @@
 """
 import torch
 import torch.nn as nn
-from pfrl.initializers import init_lecun_normal
+
+from pfrl.initializers.lecun_normal import init_lecun_normal
 
 
 @torch.no_grad()
